from django.contrib.auth import views as auth_views
from django.urls import reverse_lazy, path
from . import views


urlpatterns = [
    # Login and logout
    path(
        "login/",
        auth_views.LoginView.as_view(template_name="neluser/login.html"),
        name="login",
    ),
    path(
        "logout/",
        auth_views.LogoutView.as_view(next_page=reverse_lazy("index")),
        name="logout",
    ),
    # Account activation
    path("register/", views.register, name="register"),
    path("activate/<uidb64>/<token>/", views.activate, name="activate"),
    # Forgotten password
    path(
        "forgotten_password/",
        auth_views.PasswordResetView.as_view(
            template_name="neluser/password_reset.html",
            email_template_name="neluser/password_reset_email.txt",
            html_email_template_name="neluser/password_reset_email.html",
            subject_template_name="neluser/password_reset_email_subject.txt",
        ),
        name="password_reset",
    ),
    path(
        "forgotten_password/done/",
        auth_views.PasswordResetDoneView.as_view(
            template_name="neluser/password_reset_email_sent.html"
        ),
        name="password_reset_done",
    ),
    path(
        "password/reset/<uidb64>/<token>/",
        auth_views.PasswordResetConfirmView.as_view(
            template_name="neluser/password_reset_confirm.html"
        ),
        name="password_reset_confirm",
    ),
    path(
        "password/reset/done/",
        auth_views.PasswordResetCompleteView.as_view(
            template_name="neluser/password_reset_done.html"
        ),
        name="password_reset_complete",
    ),
    # --------
    # Settings
    # --------
    path("settings/", views.settings_default, name="settings"),
    # Preferences
    path("settings/preferences/nsfw/", views.set_nsfw, name="set_nsfw"),
    # Security
    path(
        "settings/security/password/",
        views.ChangePasswordView.as_view(),
        name="password_change",
    ),
    path(
        "settings/security/delete_account/",
        views.DeleteAccountView.as_view(),
        name="delete_account",
    ),
]
